function A=randntriu(N,d,varargin)
% FUNCTION fc_amat.random.randntriu
% -- fc_amat.random.randntriu(N,d)
%      Returns a N-by-d-by-d amat object whose matrices are upper triangular  
%      with non zeros elements drawn from the normal distribution having zero 
%      mean and unit standard deviation.
%      
% -- fc_amat.random.randntriu(...,key,value)
%      Optional key/value pairs pairs arguments are available with keys:
%        - 'nc',  number of columns of matrices (default: d)
%        - 'k',  offset of k diagonals above or below the main diagonal; above 
%          for positive k and below for negative k.
%        - 'complex', if value is true the amat object is complex 
%                     (default false i.e real amat object)
%        - 'class', value can be 'single' or 'double' (default).
%        - 'mean', to set mean value (0 by default).
%        - 'sigma', to set  standard deviation value (1 by default).
%
%      See also: fc_amat.random.randtriu, fc_amat.random.randitriu,
%                class amat, randn
%
  p = inputParser;
  p.addParamValue('nc',d,@isscalar); % number of columns
  p.addParamValue('k',0,@isscalar); % diag number
  p.addParamValue('class','double',@(x) ismember(lower(x),{'single','double'})); 
  p.addParamValue('complex',false,@islogical);
  p.addParamValue('mean',0,@isscalar); 
  p.addParamValue('sigma',1,@isscalar);
  
  p.parse(varargin{:});
  sigma=p.Results.sigma;
  mean=p.Results.mean;
  nc=p.Results.nc;k=p.Results.k;
  classname=p.Results.class;
  if p.Results.complex
    A=complex(amat(N,d,nc,classname));
    gen=@(e) complex(mean+sigma*randn(N,e,classname),mean+sigma*rand(N,e,classname));
  else
    A=amat(N,d,nc,classname);
    gen=@(e) mean+sigma*randn(N,e,classname);
  end
  for i=1:min(d,nc)
    s=max(1,i+k);
    if s<=nc, A(i,s:nc)=gen(nc-(s)+1); end
  end
end
